geo_aid_script

Module token

All functionality for turning scripts into series of tokens.

Modules

  • Functionality for parsing numbers, including managing operations with arbitrary precision.

Structs

Enums

  • An identifier. Either a point collection or a name.
  • A number token. Can represent an integer or a decimal.
  • Any valid token of GeoScript

Functions

  • Tokenizes the given script (turns it into a series of tokens).