All functionality for turning scripts into series of tokens.
Modules
- Functionality for parsing numbers, including managing operations with arbitrary precision.
Structs
- A ‘&’ token.
- A ‘*’ token.
- A ‘@’ token.
- A ‘^’ token.
- A ‘:’ token.
- A ‘,’ token.
- A ‘$’ token.
- A ‘.’ token.
- A ‘=’ token.
- A ‘!’ token.
- A ‘>’ token.
- A ‘>=’ token.
- A ‘{’ token.
- A ‘(’ token.
- A ‘[’ token.
- A ‘let’ token.
- A ‘<’ token.
- A ‘<=’ token.
- A ‘-’ token.
- A name identifier, as opposed to a point collection identifier. For more details, see
PointCollection - A ‘+’ token.
- A point collection composed of single point identifiers. A point identifier is an uppercase alphabetic character and a number of
'characters following it. - An item of a point collection.
- Defines a position in the script.
- A ‘?’ token.
- A ‘}’ token.
- A ‘)’ token.
- A ‘]’ token.
- A ‘;’ token.
- A ‘/’ token.
- Defines a span in the script.
- A string, delimited by quotation marks.
- A decimal number.
- An integer.
- A ‘|’ token.
Enums
- An identifier. Either a point collection or a name.
- A number token. Can represent an integer or a decimal.
- Any valid token of
GeoScript
Functions
- Tokenizes the given script (turns it into a series of tokens).